<?php
/**
 * The template for adding Featured Content Settings in Customizer
 *
 * @package foodland
 * @subpackage Foodland Pro
 * @since Foodland 1.0
 */

// Featured Content Setting Starts
	$wp_customize->add_section( 'foodland_featured_content_settings', array(
		'title'				=> __( 'Featured Content', 'foodland' ),
		'description'		=> __( 'Options for featured content', 'foodland' ),
		'priority'      	=> 400,
	) );

	$wp_customize->add_setting( 'foodland_theme_options[featured_content_option]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_option'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$foodland_featured_slider_content_options = foodland_section_control_options();
	$choices = array();
	foreach ( $foodland_featured_slider_content_options as $foodland_featured_slider_content_option ) {
		$choices[$foodland_featured_slider_content_option['value']] = $foodland_featured_slider_content_option['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[featured_content_option]', array(
		'choices'  			=> $choices,
		'label'    			=> __( 'Enable Featured Content on', 'foodland' ),
		'priority'			=> '1',
		'section'  			=> 'foodland_featured_content_settings',
		'settings' 			=> 'foodland_theme_options[featured_content_option]',
		'type'	  			=> 'select',
	) );

	//check is jetpack is active
	if( ( 'featured-food-menus' == $options['featured_content_type'] ) && !class_exists( 'jetpack' ) ){
		$description  = sprintf( __( 'Food Menu requires ', 'foodland' ) .'<a target="_blank" href="'. esc_url( 'https://wordpress.org/plugins/jetpack/' ) .'">'. __( 'JetPack Plugin', 'foodland' ) . '</a>.' );
	}
	else{
		$description = __( 'Save and Refresh page if option is changed.', 'foodland' );
	}

	$wp_customize->add_setting( 'foodland_theme_options[featured_content_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_type'],
		'sanitize_callback'	=> 'foodland_sanitize_select',
	) );

	$foodland_featured_content_types = foodland_featured_content_types();
	$choices = array();

	foreach ( $foodland_featured_content_types as $foodland_featured_content_type ) {
		$choices[$foodland_featured_content_type['value']] = $foodland_featured_content_type['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[featured_content_type]', array(
		'active_callback' => 'foodland_is_featured_content_active',
		'choices'         => $choices,
		'label'           => __( 'Select Content Type', 'foodland' ),
		'description'     => $description,
		'priority'        => '3',
		'section'         => 'foodland_featured_content_settings',
		'settings'        => 'foodland_theme_options[featured_content_type]',
		'type'            => 'select',
	) );

	//loop for featured post content
	for ( $i=1; $i <= 8; $i++ ) {
		$wp_customize->add_setting( 'foodland_theme_options[featured_content_post_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'foodland_sanitize_page',
		) );

		$wp_customize->add_control( 'foodland_featured_content_post_'. $i, array(
			'active_callback' 	=> 'foodland_is_featured_post_content_active',
			'input_attrs'     	=> array(
				'style'         => 'width: 70px;',
				'placeholder'   => __( 'Post ID', 'foodland' ),
			),
			'label'           	=> __( 'Featured Post', 'foodland' ) . ' ' . $i ,
			'description'		=> __( 'Enter post ID', 'foodland' ),
			'priority'        	=>  '4' . $i,
			'section'         	=> 'foodland_featured_content_settings',
			'settings'        	=> 'foodland_theme_options[featured_content_post_'. $i .']',
			'type'            	=> 'text',
			)
		);

		$wp_customize->add_setting( 'foodland_theme_options[featured_content_page_'. $i .']', array(
			'capability'        => 'edit_theme_options',
			'default'			=> $defaults['dropdown_page_default'],
			'sanitize_callback'	=> 'foodland_sanitize_page',
		) );

		$wp_customize->add_control( 'foodland_featured_content_page_'. $i .'', array(
			'active_callback' 	=> 'foodland_is_featured_page_content_active',
			'label'           	=> __( 'Featured Page', 'foodland' ) . ' ' . $i ,
			'priority'        	=> '5' . $i,
			'section'         	=> 'foodland_featured_content_settings',
			'settings'        	=> 'foodland_theme_options[featured_content_page_'. $i .']',
			'type'            	=> 'dropdown-pages',
		) );
		
		$wp_customize->add_setting( 'foodland_theme_options[featured_content_note_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Foodland_Note_Control( $wp_customize, 'featured_content_note_'. $i, array(
			'active_callback'	=> 'foodland_is_featured_image_content_active',
	        'label'				=> __( 'Featured Content #', 'foodland' ) .  $i,
			'priority'			=> '6' . '.' . $i,
	        'section'  			=> 'foodland_featured_content_settings',
	        'settings'			=> 'foodland_theme_options[featured_content_note_'. $i .']',
	        'type'     			=> 'description',
   		) ) );

   		$wp_customize->add_setting( 'foodland_theme_options[featured_content_title_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control(  'foodland_theme_options[featured_content_title_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_featured_image_content_active',
			'label'           	=> __( 'Title', 'foodland' ),
			'priority'        	=> '6' . '.' .$i .  $i,
			'section'         	=> 'foodland_featured_content_settings',
			'settings'        	=> 'foodland_theme_options[featured_content_title_'. $i .']',
			'type'           	=> 'text',
	    ) );

		$wp_customize->add_setting( 'foodland_theme_options[featured_content_image_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'absint',
		) );

		$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'featured_content_image_'. $i , array(
			'active_callback' 	=> 'foodland_is_featured_image_content_active',
			'label'           	=> __( 'Image', 'foodland' ),
			'description'     	=> __( '* Prefered image size is 336px * 247px', 'foodland' ),
			'priority'        	=> '6' . '.' . $i . $i . $i,
			'section'         	=> 'foodland_featured_content_settings',
			'settings'        	=> 'foodland_theme_options[featured_content_image_'. $i .']',
			'flex_width'      	=> false, // Allow any width, making the specified value recommended. False by default.
			'flex_height'     	=> false, // Require the resulting image to be exactly as tall as the height attribute (default).
			'width'           	=> 336,
			'height'          	=> 224,
		) ) );

		$wp_customize->add_setting( 'foodland_theme_options[featured_content_link_'. $i .']', array(
			'capability'        => 'edit_theme_options',
			'sanitize_callback'	=> 'esc_url_raw',
		) );

		$wp_customize->add_control(  'foodland_theme_options[featured_content_link_'. $i .']', array(
			'active_callback' 	=> 'foodland_is_featured_image_content_active',
			'label'           	=> __( 'Link', 'foodland' ),
			'priority'        	=> '6' . '.' .$i . $i  . $i . $i ,
			'section'         	=> 'foodland_featured_content_settings',
			'settings'        	=> 'foodland_theme_options[featured_content_link_'. $i .']',
			'type'            	=> 'url'
		) );

	    //nova menu jetpack support
		if( class_exists( 'jetpack' ) ){ 
		    $wp_customize->add_setting( 'foodland_theme_options[featured_food_items_'.$i.']', array(
				'capability'        => 'edit_theme_options',
				'default'			=> $defaults['dropdown_page_default'],
				'sanitize_callback' => 'absint',
			) );

			$wp_customize->add_control( new Foodland_Customize_Dropdown_Nova_Menu( $wp_customize, 'foodland_theme_options[featured_food_items_'.$i.']', array(
				'active_callback' 	=> 'foodland_is_featured_food_menu_content_active',
				'label'           	=> __('Select Menu Item ', 'foodland' ).$i,
				'name'            	=> 'foodland_theme_options[featured_food_items_'.$i.']',
				'priority'        	=> '6' . '.' .$i  .$i  . $i . $i . $i . $i,
				'section'         	=> 'foodland_featured_content_settings',
				'type'            	=> 'nova-menu',
		    ) ) );	
		}
	}
// Featured Content Setting End