<?php
/**
 * The template for adding additional theme options in Customizer
 *
 * @package Theme Palace
 * @subpackage Foodland Pro
 * @since Foodland 1.0 
 */

//Theme Options
	$wp_customize->add_panel( 'foodland_theme_options', array(
		'description' 		=> __( 'Basic theme Options', 'foodland' ),
		'capability'  		=> 'edit_theme_options',
		'priority'    		=> 700,
		'title'       		=> __( 'Theme Options', 'foodland' ),
	) );

	// Check if contact form seven plugin and jetpack plugin is active.
	if( class_exists( 'WPCF7' ) && class_exists( 'jetpack' ) ){
		// Contact form 7
		$wp_customize->add_section( 'foodland_contact_form_options', array(
			'description' 		=> __( 'This option let you use contact form 7 ( CF7 ) in single food menu items page.', 'foodland' ),
			'panel'       		=> 'foodland_theme_options',
			'title'       		=> __( 'Contact form 7', 'foodland' ),
			'priority'    		=> 200,
		) );
		$wp_customize->add_setting( 'foodland_theme_options[cf7_disable]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['cf7_disable'],
			'sanitize_callback' => 'foodland_sanitize_checkbox'
		) );

		$wp_customize->add_control( 'foodland_theme_options[cf7_disable]', array(
			'label'    			=> __( 'Disable CF7', 'foodland' ),
			'section'  			=> 'foodland_contact_form_options',
			'settings' 			=> 'foodland_theme_options[cf7_disable]',
			'type'     			=> 'checkbox',
		) );

		$wp_customize->add_setting( 'foodland_theme_options[cf7_title]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['cf7_title'],
			'sanitize_callback' => 'sanitize_text_field'
		) );

		$wp_customize->add_control( 'foodland_theme_options[cf7_title]', array(
			'active_callback'   => 'foodland_is_cf7_active',
			'label'    			=> __( 'Title', 'foodland' ),
			'description' 		=> __( 'Enter title', 'foodland' ),
			'section'  			=> 'foodland_contact_form_options',
			'settings' 			=> 'foodland_theme_options[cf7_title]',
			'type'     			=> 'text',
		) );

		$wp_customize->add_setting( 'foodland_theme_options[cf7_sub_title]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['cf7_sub_title'],
			'sanitize_callback' => 'sanitize_text_field'
		) );

		$wp_customize->add_control( 'foodland_theme_options[cf7_sub_title]', array(
			'active_callback'   => 'foodland_is_cf7_active',
			'label'    			=> __( 'Sub Title', 'foodland' ),
			'description' 		=> __( 'Enter Sub title', 'foodland' ),
			'section'  			=> 'foodland_contact_form_options',
			'settings' 			=> 'foodland_theme_options[cf7_sub_title]',
			'type'     			=> 'text',
		) );

		$wp_customize->add_setting( 'foodland_theme_options[cf7_shortcode]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['cf7_shortcode'],
			'sanitize_callback' => 'sanitize_text_field'
		) );

		$wp_customize->add_control( 'foodland_theme_options[cf7_shortcode]', array(
			'active_callback'   => 'foodland_is_cf7_active',
			'label'    			=> __( 'CF7 Shortcode', 'foodland' ),
			'description' 		=> __( 'Enter shortcode from CF7', 'foodland' ),
			'section'  			=> 'foodland_contact_form_options',
			'settings' 			=> 'foodland_theme_options[cf7_shortcode]',
			'type'     			=> 'text',
		) );
		// Contact form 7 shortcode ends.
	}

	// Breadcrumb Option
	$wp_customize->add_section( 'foodland_breadcumb_options', array(
		'description' 		=> __( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'foodland' ),
		'panel'       		=> 'foodland_theme_options',
		'title'       		=> __( 'Breadcrumb Options', 'foodland' ),
		'priority'    		=> 201,
	) );

	$wp_customize->add_setting( 'foodland_theme_options[breadcumb_option]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['breadcumb_option'],
		'sanitize_callback' => 'foodland_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'foodland_theme_options[breadcumb_option]', array(
		'label'    			=> __( 'Check to enable Breadcrumb', 'foodland' ),
		'section'  			=> 'foodland_breadcumb_options',
		'settings' 			=> 'foodland_theme_options[breadcumb_option]',
		'type'     			=> 'checkbox',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[breadcumb_onhomepage]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['breadcumb_onhomepage'],
		'sanitize_callback' => 'foodland_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'foodland_theme_options[breadcumb_onhomepage]', array(
		'label'    			=> __( 'Check to enable Breadcrumb on Homepage', 'foodland' ),
		'section'  			=> 'foodland_breadcumb_options',
		'settings' 			=> 'foodland_theme_options[breadcumb_onhomepage]',
		'type'     			=> 'checkbox',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[breadcumb_seperator]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['breadcumb_seperator'],
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'foodland_theme_options[breadcumb_seperator]', array(
		'input_attrs' 		=> array(
		'style'       		=> 'width: 40px;'
		),
		'label'       		=> __( 'Separator between Breadcrumbs', 'foodland' ),
		'section'     		=> 'foodland_breadcumb_options',
		'settings'    		=> 'foodland_theme_options[breadcumb_seperator]',
		'type'        		=> 'text'
	) );
   	// Breadcrumb Option End
   	
	if ( version_compare( $GLOBALS['wp_version'], '4.7', '<' ) ) {

   	// Custom CSS Option
	$wp_customize->add_section( 'foodland_custom_css', array(
		'description'		=> __( 'Custom/Inline CSS', 'foodland'),
		'panel'  			=> 'foodland_theme_options',
		'priority' 			=> 203,
		'title'    			=> __( 'Custom CSS Options', 'foodland' ),
	) );

	$wp_customize->add_setting( 'foodland_theme_options[custom_css]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['custom_css'],
		'sanitize_callback' => 'foodland_sanitize_custom_css',
	) );

	$wp_customize->add_control( 'foodland_theme_options[custom_css]', array(
		'label'				=> __( 'Enter Custom CSS', 'foodland' ),
        'priority'			=> 1,
		'section'   		=> 'foodland_custom_css',
        'settings'  		=> 'foodland_theme_options[custom_css]',
		'type'				=> 'textarea',
	) );
   	// Custom CSS End
	}

   	// Excerpt Options
	$wp_customize->add_section( 'foodland_excerpt_options', array(
		'panel'  			=> 'foodland_theme_options',
		'priority' 			=> 204,
		'title'    			=> __( 'Excerpt Options', 'foodland' ),
	) );

   	// Excerpt Options for Archive contents
	$wp_customize->add_setting( 'foodland_theme_options[excerpt_length]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['excerpt_length'],
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'foodland_theme_options[excerpt_length]', array(
		'description' 		=> __('Excerpt length. Default is 55 words', 'foodland'),
		'priority'    		=> '1',
		'input_attrs' 		=> array(
			'min'         	=> 10,
			'max'         	=> 200,
			'step'        	=> 5,
			'style'       	=> 'width: 60px;'
		),
		'label'       		=> __( 'Excerpt Length (words)', 'foodland' ),
		'section'     		=> 'foodland_excerpt_options',
		'settings'    		=> 'foodland_theme_options[excerpt_length]',
		'type'        		=> 'number',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[excerpt_more_text]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['excerpt_more_text'],
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'foodland_theme_options[excerpt_more_text]', array(
		'label'    			=> __( 'Read More Text', 'foodland' ),
		'priority' 			=> '2',
		'section'  			=> 'foodland_excerpt_options',
		'settings'			=> 'foodland_theme_options[excerpt_more_text]',
		'type'	   			=> 'text',
	) );

	// Excerpt Options for Featured slider
	$wp_customize->add_setting( 'foodland_theme_options[slider_excerpt_length]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['slider_excerpt_length'],
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'foodland_theme_options[slider_excerpt_length]', array(
		'description' 		=> __('Slider Excerpt length. Maximum 40 Words', 'foodland'),
		'priority'    		=> '3',
		'input_attrs' 		=> array(
			'min'         	=> 10,
			'max'         	=> 40,
			'step'        	=> 5,
			'style'       	=> 'width: 60px;'
		),
		'label'       		=> __( 'Slider Excerpt Length ( Words )', 'foodland' ),
		'section'     		=> 'foodland_excerpt_options',
		'settings'    		=> 'foodland_theme_options[slider_excerpt_length]',
		'type'        		=> 'number',
		)
	);
	// Excerpt Options End

	// Font Family Options
	$wp_customize->add_section( 'foodland_font_family', array(
		'panel'    			=> 'foodland_theme_options',
		'priority' 			=> 206,
		'title'    			=> __( 'Font Family Options', 'foodland' ),
	) );

	$avaliable_fonts = foodland_avaliable_fonts();
	
	$choices         = array();
	
	foreach ( $avaliable_fonts as $avaliable_font ) {
		$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
	}

	$font_family_options	=	array(
										'title_font' 		=> __( 'Site Title Font Family', 'foodland' ),
										'tagline_font' 		=> __( 'Site Tagline Font Family', 'foodland' ),
										'body_font' 		=> __( 'Default Font Family', 'foodland' ),
										'content_title_font'=> __( 'Content Title Font Family', 'foodland' ),
										'content_font' 		=> __( 'Content Body Font Family', 'foodland' ),
										'headings_font' 	=> __( 'Headings Tags from h1 to h6 Font Family', 'foodland' ) 
									);

	foreach ( $font_family_options as $key => $font_family_option ) {
		$wp_customize->add_setting( 'foodland_theme_options['. $key . ']', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults[ $key ],
			'sanitize_callback' => 'foodland_sanitize_select',
		) );

		$wp_customize->add_control( 'foodland_theme_options['. $key . ']', array(
			'choices'  			=> $choices,
			'label'    			=> $font_family_option,
			'section'  			=> 'foodland_font_family',
			'settings' 			=> 'foodland_theme_options['. $key . ']',
			'type'	   			=> 'select',
		) );
	}

	$wp_customize->add_setting( 'foodland_theme_options[reset_typography]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['reset_typography'],
		'sanitize_callback' => 'foodland_reset_typography'
	) );

	$wp_customize->add_control( 'foodland_theme_options[reset_typography]', array(
		'label'				=> __( 'Check to reset fonts', 'foodland' ),
		'description'		=> __( 'Save and Refresh page to use default fonts.', 'foodland' ),
		'section'			=> 'foodland_font_family',
		'settings'			=> 'foodland_theme_options[reset_typography]',
		'type'				=> 'checkbox',
	) );
	// Font Family Options End
	
	// Footer Editor Options
	$wp_customize->add_section( 'foodland_footer_options', array(
		'description'		=> __( 'You can either add html or plain text', 'foodland'),
		'panel'  			=> 'foodland_theme_options',
		'priority' 			=> 207,
		'title'    			=> __( 'Footer Editor Options', 'foodland' ),
	) );

	$wp_customize->add_setting( 'foodland_theme_options[footer_content]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['footer_content'],
		'sanitize_callback'	=> 'foodland_sanitize_footer_code',
	) );

	$wp_customize->add_control( 'foodland_theme_options[footer_content]', array(
		'description' 		=> __( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year] and [site-link] for current year and site link respectively.', 'foodland' ),
		'label'       		=> __( 'Footer Content', 'foodland' ),
		'priority'    		=> 1,
		'section'     		=> 'foodland_footer_options',
		'settings'    		=> 'foodland_theme_options[footer_content]',
		'type'        		=> 'textarea',
	) );
	// Footer Options End

	// Layout Options
	$wp_customize->add_section( 'foodland_layout', array(
		'capability'		=> 'edit_theme_options',
		'panel'				=> 'foodland_theme_options',
		'priority'			=> 211,
		'title'				=> __( 'Layout Options', 'foodland' ),
	) );

	$wp_customize->add_setting( 'foodland_theme_options[content_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['content_layout'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$layouts = foodland_get_archive_content_layout();
	$choices = array();

	foreach ( $layouts as $layout ) {
		$choices[ $layout['value'] ] = $layout['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[content_layout]', array(
		'choices'   		=> $choices,
		'label'				=> __( 'Archive Content Layout', 'foodland' ),
		'section'   		=> 'foodland_layout',
		'settings'  		=> 'foodland_theme_options[content_layout]',
		'type'      		=> 'select',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[single_post_image_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['single_post_image_layout'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	
	$single_post_image_layouts = foodland_single_post_image_layout_options();
	$choices                   = array();

	foreach ( $single_post_image_layouts as $single_post_image_layout ) {
		$choices[$single_post_image_layout['value']] = $single_post_image_layout['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[single_post_image_layout]', array(
		'label'				=> __( 'Single Page/Post Image Layout ', 'foodland' ),
		'section'   		=> 'foodland_layout',
        'settings'  		=> 'foodland_theme_options[single_post_image_layout]',
        'type'	  			=> 'select',
		'choices'  			=> $choices,
	) );
   	// Layout Options End
	
	// Pagination Options
	$pagination_type	= $options['pagination_type'];

	$foodland_navigation_description = sprintf( __( 'Numeric Option requires', 'foodland' ) . '<a target="_blank" href="'. esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ) .'">'. __( ' WP-PageNavi Plugin ', 'foodland' ) . '</a>.<br/>' . __( 'Infinite Scroll Options requires', 'foodland' ) . '<a target="_blank" href="'. esc_url( 'https://wordpress.org/plugins/jetpack/' ) .'">' .__( ' JetPack Plugin ', 'foodland' ). '</a>' .__( 'with Infinite Scroll module Enabled', 'foodland' ) );
	
	/**
	 * Check if navigation type is Jetpack Infinite Scroll and if it is enabled
	 */
	if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) ) {
		if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) ) {
			$foodland_navigation_description = sprintf( __( 'Infinite Scroll Options requires', 'foodland' ) . '<a target="_blank" href="'. esc_url( 'https://wordpress.org/plugins/jetpack/' ) .'">'. __( ' JetPack Plugin ', 'foodland' ).'</a>'. __( 'with Infinite Scroll module Enabled.', 'foodland' ) );
		}
		else {
			$foodland_navigation_description = '';
		}
	}
	/**
	* Check if navigation type is numeric and if Wp-PageNavi Plugin is enabled
	*/
	else if ( 'numeric' == $pagination_type ) {
		if ( !function_exists( 'wp_pagenavi' ) ) {
			$foodland_navigation_description = sprintf( __( 'Numeric Option requires', 'foodland') . '<a target="_blank" href="' . esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ) . '">' . __( ' WP-PageNavi Plugin ', 'foodland' ) .'</a>' );
		}
		else {
			$foodland_navigation_description = '';
		}
    }

	$wp_customize->add_section( 'foodland_pagination_options', array(
		'description'		=> $foodland_navigation_description,
		'panel'  			=> 'foodland_theme_options',
		'priority'			=> 212,
		'title'    			=> __( 'Pagination Options', 'foodland' ),
	) );

	$wp_customize->add_setting( 'foodland_theme_options[pagination_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['pagination_type'],
		'sanitize_callback' => 'foodland_sanitize_select',
	) );

	$pagination_types = foodland_get_pagination_types();
	$choices          = array();

	foreach ( $pagination_types as $pagination_type ) {
		$choices[$pagination_type['value']] = $pagination_type['label'];
	}

	$wp_customize->add_control( 'foodland_theme_options[pagination_type]', array(
		'choices'  			=> $choices,
		'label'    			=> __( 'Pagination type', 'foodland' ),
		'description'		=> __( 'Infinite scroll is disabled for Food Menus', 'foodland'),
		'section'  			=> 'foodland_pagination_options',
		'settings' 			=> 'foodland_theme_options[pagination_type]',
		'type'	   			=> 'select',
	) );
	// Pagination Options End

	// Scrollup
	$wp_customize->add_section( 'foodland_scrollup', array(
		'panel'    			=> 'foodland_theme_options',
		'priority' 			=> 215,
		'title'    			=> __( 'Scrollup Options', 'foodland' ),
	) );

	$wp_customize->add_setting( 'foodland_theme_options[enable_scrollup]', array(
		'capability'		=> 'edit_theme_options',
        'default'			=> $defaults['enable_scrollup'],
		'sanitize_callback' => 'foodland_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'foodland_theme_options[enable_scrollup]', array(
		'label'				=> __( 'Check to enable Scroll Up', 'foodland' ),
		'section'   		=> 'foodland_scrollup',
        'settings'  		=> 'foodland_theme_options[enable_scrollup]',
		'type'				=> 'checkbox',
	) );
	// Scrollup End

	// Search Options
	$wp_customize->add_section( 'foodland_search_options', array(
		'description' 		=> __( 'Change default placeholder text in Search.', 'foodland'),
		'panel'       		=> 'foodland_theme_options',
		'priority'    		=> 216,
		'title'       		=> __( 'Search Options', 'foodland' ),
	) );

	$wp_customize->add_setting( 'foodland_theme_options[search_text]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['search_text'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'foodland_theme_options[search_text]', array(
		'label'				=> __( 'Default Display Text in Search', 'foodland' ),
		'section'   		=> 'foodland_search_options',
        'settings'  		=> 'foodland_theme_options[search_text]',
		'type'				=> 'text',
	) );
	// Search Options End

	//social icons starts
	$wp_customize->add_section( 'foodland_social_links', array(
		'panel'				=> 'foodland_theme_options',
		'priority' 			=> 217,
		'title'   	 		=> __( 'Social Links', 'foodland' ),
	) );

	$wp_customize->add_setting( 'foodland_theme_options[disable_social_icon]', array(
		'capability'		=> 'edit_theme_options',
		'default' 			=> $defaults['disable_social_icon'],
		'sanitize_callback'	=> 'foodland_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'foodland_theme_options[disable_social_icon]', array(
		'label'				=> __( 'Check to Disable Footer Social Media Icons', 'foodland' ),
		'priority'			=> '1',
		'section'   		=> 'foodland_social_links',
		'settings'  		=> 'foodland_theme_options[disable_social_icon]',
		'type'				=> 'checkbox',
	) );

	$foodland_social_icons 	=	foodland_get_social_icons_list();

	foreach ( $foodland_social_icons as $key => $value ){
		if( 'skype_link' == $key ){
			$wp_customize->add_setting( 'foodland_theme_options['. $key .']', array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_text_field',
				) );

			$wp_customize->add_control( 'foodland_theme_options['. $key .']', array(
				'active_callback' => 'foodland_is_footer_social_links_active',
				'description'     => __( 'Skype link can be of formats:<br>callto://+{number}<br> skype:{username}?{action}. More Information in readme file', 'foodland' ),
				'label'           => $value['label'],
				'section'         => 'foodland_social_links',
				'settings'        => 'foodland_theme_options['. $key .']',
				'type'            => 'text',
			) );
		}
		else if( 'email_link' == $key ){
			$wp_customize->add_setting( 'foodland_theme_options['. $key .']', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback' => 'sanitize_email',
			) );
			$wp_customize->add_control( 'foodland_theme_options['. $key .']', array(
				'active_callback' => 'foodland_is_footer_social_links_active',
				'label'           => $value['label'],
				'section'         => 'foodland_social_links',
				'settings'        => 'foodland_theme_options['. $key .']',
				'type'            => 'email',
			) );
		}
		else if( 'handset_link' == $key || 'phone_link' == $key ){
			$wp_customize->add_setting( 'foodland_theme_options['. $key .']', array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_text_field',
			) );
			$wp_customize->add_control( 'foodland_theme_options['. $key .']', array(
				'active_callback' => 'foodland_is_footer_social_links_active',
				'label'           => $value['label'],
				'section'         => 'foodland_social_links',
				'settings'        => 'foodland_theme_options['. $key .']',
				'type'            => 'text',
			) );
		}
		else {
			$wp_customize->add_setting( 'foodland_theme_options['. $key .']', array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_url_raw',
			) );

			$wp_customize->add_control( 'foodland_theme_options['. $key .']', array(
				'active_callback' => 'foodland_is_footer_social_links_active',
				'label'           => $value['label'],
				'section'         => 'foodland_social_links',
				'settings'        => 'foodland_theme_options['. $key .']',
				'type'            => 'url',
			) );
		}
	}
	// Social Icons End

	// Update Notifier
	$wp_customize->add_section( 'foodland_update_notifier', array(
		'title'    			=> __( 'Update Notifier', 'foodland' ),
		'priority' 			=> 220,
		'panel'    			=> 'foodland_theme_options',
	) );

	$wp_customize->add_setting( 'foodland_theme_options[update_notifier]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['update_notifier'],
		'sanitize_callback' => 'foodland_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'foodland_theme_options[update_notifier]', array(
		'label'				=> __( 'Check to disable update notifications', 'foodland' ),
		'section'   		=> 'foodland_update_notifier',
        'settings'  		=> 'foodland_theme_options[update_notifier]',
		'type'				=> 'checkbox',
	) );
	// Update Notifier End
//Theme Option End