<?php
/**
 * The template for displaying meta box in page/post and Nova menu items( JetPack )
 *
 * This adds Layout Options, Select Sidebar, Header Freatured Image Options, Single Page/Post Image Layout
 * This is only for the design purpose and not used to save any content
 *
 * @package Theme Palace
 * @subpackage Foodland Pro
 * @since Foodland 1.0 
 */

/**
 * Class to Renders and save metabox options
 *
 * @since Foodland 1.0
 */
class FoodlandMetaBox {
	private $meta_box;

	private $fields;

	/**
	* Constructor
	*
	* @since Foodland 1.0
	*
	* @access public
	*
	*/
	public function __construct( $meta_box_id, $meta_box_title, $post_type ) {
		
		$this->meta_box = array (
							'id' 		=> $meta_box_id,
							'title' 	=> $meta_box_title,
							'post_type' => $post_type,
							);

		$this->fields = array(
								'foodland-header-image',
								'foodland-featured-image',
							);


		// Add metaboxes
		add_action( 'add_meta_boxes', array( $this, 'add' ) );
		
		add_action( 'save_post', array( $this, 'save' ) );	
   	}

	/**
	* Add Meta Box for multiple post types.
	*
	* @since food-land 1.0.
	*
	* @access public
	*/
	public function add($postType) {
		if( in_array( $postType, $this->meta_box['post_type'] ) ) {
			add_meta_box( $this->meta_box['id'], $this->meta_box['title'], array( $this, 'show' ), $postType, 'side' );
		}
	}

	/**
	* Renders metabox
	*
	* @since Foodland 1.0
	*
	* @access public
	*/
	public function show() {
		global $post;

		$featured_image_options	= foodland_metabox_featured_image_options();  
		$header_image_options 	= foodland_metabox_header_featured_image_options();		
	    
	    // Use nonce for verification  
	    wp_nonce_field( basename( __FILE__ ), 'foodland_custom_meta_box_nonce' );

	    // Begin the field table and loop  ?>  
	    <div id="foodland-ui-tabs" class="ui-tabs">
	    
		    <ul class="foodland-ui-tabs-nav" id="foodland-ui-tabs-nav">
		    	<li><a href="#frag3"><?php _e( 'Header Featured Image Options', 'foodland' ); ?></a></li>
		    	<li><a href="#frag4"><?php _e( 'Single Page/Post Image Layout ', 'foodland' ); ?></a></li>
		    </ul>

	    	<div id="frag3" class="catch_ad_tabhead">
		    	<table id="header-image-metabox" class="form-table" width="100%">
		            <tbody> 
		                <tr>                
		                    <?php  
		                    foreach ( $header_image_options as $field ) { 
							
							 	$metaheader = get_post_meta( $post->ID, $field['id'], true );
		                        
		                        if ( empty( $metaheader ) ){
		                            $metaheader='default';
		                        }
		                    ?>
		                        
		                        <td style="width: 100px;">
		                            <label class="description">
		                                <input type="radio" name="<?php echo esc_attr( $field['id'] ); ?>" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( esc_attr( $field['value'] ), $metaheader ); ?>/>&nbsp;&nbsp;<?php echo esc_html( $field['label'] ); ?>
		                            </label>
		                        </td>
		                        
		                    <?php
		                    } // end foreach 
		                    ?>
		                </tr>
		            </tbody>
		        </table>
		    </div>

		    <div id="frag4" class="catch_ad_tabhead">
		    	<table id="featured-image-metabox" class="form-table" width="100%">
		            <tbody> 
		                <tr>
		                    <?php
		                    foreach ($featured_image_options as $field) { 
							
							 	$metaimage = get_post_meta( $post->ID, $field['id'], true );
		                        
		                        if (empty( $metaimage ) ){
		                            $metaimage='default';
		                        } 
		                    ?>
		                        <td style="width: 100px;">
		                            <label class="description">
		                                <input type="radio" name="<?php echo esc_attr( $field['id'] ); ?>" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( esc_attr( $field['value'] ), $metaimage ); ?>/>&nbsp;&nbsp;<?php echo esc_html( $field['label'] ); ?>
		                            </label>
		                        </td>
		                
		                    <?php
		                    } // end foreach 
		                    ?>
		                </tr>
		            </tbody>
		        </table> 
		    </div>
		</div>
	<?php 
	}

	/**
	 * Save custom metabox data
	 * 
	 * @action save_post
	 *
	 * @since Foodland 1.0
	 *
	 * @access public
	 */
	public function save( $post_id ) { 
		global $post_type;
    
		$post_type_object = get_post_type_object( $post_type );

	    if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )                      // Check Autosave
	    || ( ! isset( $_POST['post_ID'] ) || $post_id != $_POST['post_ID'] )        // Check Revision
	    || ( ! in_array( $post_type, $this->meta_box['post_type'] ) )                  // Check if current post type is supported.
	    || ( ! check_admin_referer( basename( __FILE__ ), 'foodland_custom_meta_box_nonce') )    // Check nonce - Security
	    || ( ! current_user_can( $post_type_object->cap->edit_post, $post_id ) ) )  // Check permission
	    {
	      return $post_id;
	    }

	    foreach ( $this->fields as $field ) {      
			$old = get_post_meta( $post_id, $field, true); 
			
			$new = $_POST[ $field ];

			delete_post_meta( $post_id, $field );			
			
			if ( '' == $new || array() == $new ) {
				return;
			}
			else {
				if ( ! update_post_meta ($post_id, $field, sanitize_key ( $new ) ) ) { 
					add_post_meta($post_id, $field, sanitize_key ( $new ), true );
				}
			}
		} // end foreach		 
	}
}

$foodland_metabox = new FoodlandMetaBox( 
									'foodland-options', 					//metabox id
									__( 'Foodland Options', 'foodland' ), //metabox title
									array( 'page', 'post', 'nova_menu_item' )				//metabox post types
									);



/**
* Adding metabox to add nova item rating option for nova_menu_type
*/

function foodland_metabox_menu_item_rating() {
    add_meta_box( 'menu_item_rating_metabox',
        'Foodland Menu Rating',
        'foodland_display_menu_item_rating_metabox',
        'nova_menu_item', 'side', 'low'
    );
}

function foodland_display_menu_item_rating_metabox( $menu_item_rating ) {
    // Retrieve Rating of food menu items

    $menu_rating = intval( get_post_meta( $menu_item_rating->ID, 'menu_rating', true ) );
    ?>
    <table>
        <tr>
            <td style="width: 150px"><?php _e( 'Menu Rating( Out of 5 )', 'foodland' ) ?></td>
            <td>
                <select style="width: 100px" name="menu_item_rating">
                <?php
                // Generate all items of drop-down list
                $ratings = foodland_metabox_nova_item_rating();

                foreach ($ratings as $rating) {            
                ?>
                    <option value="<?php echo esc_attr( $rating['value'] ); ?>" <?php echo selected( esc_attr( $rating['value'] ), $menu_rating ); ?>>
                    <?php echo esc_html( $rating['label'] ); ?> <?php } ?>
                </select>
            </td>
        </tr>
    </table>
    <?php
}

function add_menu_item_rating_fields( $menu_item_rating_id, $menu_item_rating ) {
    // Check if post type is nova_menu_item
    if ( $menu_item_rating->post_type == 'nova_menu_item' ) {

        // Update rating value with current rating
        if ( isset( $_POST['menu_item_rating'] ) && $_POST['menu_item_rating'] != '' ) {
            update_post_meta( $menu_item_rating_id, 'menu_rating', sanitize_key( $_POST['menu_item_rating'] ) );
        }
    }
}

add_action( 'admin_init', 'foodland_metabox_menu_item_rating' );

add_action( 'save_post', 'add_menu_item_rating_fields', 10, 2 );