<?php
/**
 * Adds food menu section widget.
 *
 * @package foodland
 * @subpackage Foodland Pro
 * @since Foodland 1.0
 */

class Foodland_fooditems_from_menu_section_widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'foodland_fooditems_from_menu_section', // Base ID
			__( 'TP: Food items from Menu Section', 'foodland' ), // Name
			array( 'description' => __( 'Use this widget to add food items from a menu section (jetpack ). ', 'foodland' ) ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		$title = isset( $instance['title'] ) ? $instance['title'] : '';

		$section_id       = ! empty( $instance['section_id'] ) ? $instance['section_id'] : '';
		
		$no_of_menu_items = ! empty( $instance['no_of_menu_items'] ) ? $instance['no_of_menu_items'] : '';

		echo $args['before_widget'];

		if ( ! empty( $title ) ){
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		}
		echo '<ul>';
			$post_args = array(
				'post_type'      => 'nova_menu_item',
				'tax_query'      => array(
	        		array(
						'taxonomy' => 'nova_menu',
						'field'    => 'term_id',	
						'terms'    => $section_id 
					)
	    		),
				'_posts_per_page'  => $no_of_menu_items,
	    		'_widget_flag' 	   => true
	    	);

		$menu_terms = 	get_posts( $post_args );		
		foreach ($menu_terms as $menu_term ) {
			$menu_title = $menu_term->post_title;
			$menu_url   = $menu_term->guid;
			echo '<li><a href="' . esc_url( $menu_url ) . '">' . esc_html( $menu_title ) . '</a></li>';			
		}
	
		wp_reset_postdata();
		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$nova_menus_terms = get_terms( 'nova_menu' );

		$title = isset( $instance['title'] ) ?	$title = $instance['title'] : '';

		$menu_section_id = isset( $instance['section_id'] ) ? $menu_section_id = $instance['section_id'] : '';

		$no_of_menu_items = isset( $instance['no_of_menu_items'] ) ? $no_of_menu_items = $instance['no_of_menu_items'] : '';

		if( !class_exists( 'jetpack' ) ){
			// Display jetpack plugin link if jetpack is not enabled
			printf( '<p>'. __( 'Requires ', 'foodland' ) . '<a href="'. esc_url( 'https://wordpress.org/plugins/jetpack/' ) .'" >'. __( 'Jetpack  Plugin ', 'foodland'). '</a></p>' );
		}
		?>

		<p>
		<label for="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>"><?php _e( 'Title (optional):', 'foodland' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		
		<p>

		<label for="<?php echo esc_attr( $this->get_field_name( 'section_id' ) ); ?>"><?php _e( 'Menu:', 'foodland' ); ?></label>
		<select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'section_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'section_id' ) ); ?>">

		<?php
		foreach ( $nova_menus_terms as $nova_menus_term )
		{
			$a = get_term_link( $nova_menus_term );
			$menu_id   = $nova_menus_term->term_id;
			$menu_name = $nova_menus_term->name;
			echo '<option value="' . esc_attr( $menu_id ) . '"' . selected( $menu_id , $menu_section_id, false ) . '>' . esc_html( $menu_name ) . '</option>'; 
		}
		?>
		</select>
	
		</p> 
		<p>
		<label for="<?php echo esc_attr( $this->get_field_name( 'no_of_menu_items' ) ); ?>"><?php _e( 'Number of Menu Items to Show:<br> -1 to show all items', 'foodland' ); ?></label>
		<input  id="<?php echo esc_attr( $this->get_field_id( 'no_of_menu_items' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'no_of_menu_items' ) ); ?>" type="number" value="<?php echo esc_attr( $no_of_menu_items ); ?>" />
		</p>
		
        <?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';

		$instance['section_id'] = ( ! empty( $new_instance['section_id'] ) ) ? strip_tags( $new_instance['section_id'] ) : '';

		$instance['no_of_menu_items'] = ( ! empty( $new_instance['no_of_menu_items'] ) ) ? strip_tags( $new_instance['no_of_menu_items'] ) : '';
		
		return $instance;
	}

} // class Foodland_fooditems_from_menu_section_widget
?>